@@ -17,7 +17,7 @@ import os # delete
 
 import junipercs.resources.commands_list as cmd_file
 import junipercs.system_parser.tokens as tokens_file
-import junipercs.system_parser.tokens_definition
+from junipercs.system_parser.tokens_definition import *
 
 # Commands
 
